Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(968)

Unified Diff: mojo/tools/run_mojo_python_tests.py

Issue 1306603002: Improve android stack parser (Closed) Base URL: git@github.com:domokit/mojo.git@master
Patch Set: Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: mojo/tools/run_mojo_python_tests.py
diff --git a/mojo/tools/run_mojo_python_tests.py b/mojo/tools/run_mojo_python_tests.py
index d18baf4f6efa4ff9af10908eac357444f704f50b..f4da223ab9b3043bf3ef0546a84220be5680ed69 100755
--- a/mojo/tools/run_mojo_python_tests.py
+++ b/mojo/tools/run_mojo_python_tests.py
@@ -15,8 +15,10 @@ def main():
os.path.join('mojo', 'public', 'tools', 'bindings', 'pylib'),
# Tests of "mopy" python tools code.
os.path.join('mojo', 'tools', 'mopy'),
- # Tests of python code in devtools.
- os.path.join('mojo', 'devtools', 'common', 'devtoolslib')
+ # Tests of python code in devtools library.
+ os.path.join('mojo', 'devtools', 'common', 'devtoolslib'),
+ # Tests of the android stack parser (in devtools).
ppi 2015/08/21 14:53:07 nit: no need to state the obvious, I'd drop this c
etiennej 2015/08/21 15:07:18 Done.
+ os.path.join('mojo', 'devtools', 'common', 'android_stack_parser')
]
for test_dir in test_dir_list:

Powered by Google App Engine
This is Rietveld 408576698